twod - Two Dimensional Geometric Objects
========================================

|pypi|  |license| |python|

**twod** is a Python 3 package that supplies simple two dimensional geometric primitives. Primitives currently include:

- twod.Point, a point class
- twod.Rect, a rectangle class

Install
-------

1. Install using pip:

.. code:: bash
	  
	  $ pip3 install twod
	  
2. Install from Github using poetry_:

.. code:: bash

	  $ git clone https://github.com/JnyJny/twod.git
	  $ cd twod; poetry install
	  
   

Uninstall
---------

Uninstall using pip:

.. code:: bash

	  $ pip3 uninstall twod

Usage
-----

``Missing``

.. _poetry: https://pypi.org/project/poetry/

.. |pypi| image:: https://img.shields.io/pypi/v/twod.svg?style=flat-square&label=version
   :target: https://pypi.org/pypi/twod
   :alt: Latest version released on PyPi
	 
.. |python| image:: https://img.shields.io/pypi/pyversions/twod.svg?style=flat-squre
   :target: https://pypi.org/project/twod
   :alt: Python Versions
		    
.. |license| image:: https://img.shields.io/badge/license-apache-blue.svg?style=flat-square
   :target: https://github.com/jnyjny/twod/blob/master/LICENSE
   :alt: Apache License v2.0
